@@ -11,7 +11,8 @@ from tensorflow.keras.callbacks import CSVLogger
 from Accuinsight.modeler.core import func, path, get
 from Accuinsight.modeler.core.func import get_time
 from Accuinsight.modeler.core.LcConst import LcConst
-from Accuinsight.modeler.core.LcConst.LcConst import RUN_NAME_TENSORFLOW
+from Accuinsight.modeler.core.LcConst.LcConst import RUN_NAME_TENSORFLOW, RUN_OBJ_NAME, RUN_MODEL_JSON_PATH, \
+    RUN_OBJ_VISUAL_JSON_PATH, RUN_MODEL_VISUAL_CSV_PATH, SELECTED_METRICS, USER_ID
 from Accuinsight.modeler.core.Run.RunInfo.RunInfo import set_current_runs, clear_runs, set_model_json_path, \
     set_visual_csv_path, set_visual_json_path, set_best_model_json_path, set_best_model_h5_path, \
     set_python_dependencies, set_run_name, set_model_file_path, set_prefix_path, set_shap_json_path
@@ -37,13 +38,19 @@ class accuinsight(Common):
         super().get_file(storage_json_file_name)
 
     @staticmethod
-    def get_run_meta():
+    def get_current_run_meta():
         global run_meta
         try:
             return run_meta
         except NameError:
             return None
 
+    def get_current_run_id(self):
+        try:
+            return self.get_current_run_meta()[RUN_OBJ_NAME]
+        except TypeError or KeyError:
+            return None
+
     def autolog(self, tag=None, best_weights=False, model_monitor=False):
         global description, endpoint, var_model_file_path, message, thresholds, best_weights_on, run_id, alarm, alarm_api, shap_on, feature_name, run_meta
         description = tag
@@ -128,7 +135,7 @@ class accuinsight(Common):
                 self.model_summary['model_type'] = get.model_type(self.model)
 
                 if user_id is not None:
-                    self.model_summary['user_id'] = user_id
+                    self.model_summary[USER_ID] = user_id
 
                 if hasattr(self.model.loss, 'get_config'):
                     self.model_summary['loss_function'] = self.model.loss.get_config()['name']
@@ -223,9 +230,9 @@ class accuinsight(Common):
                         print('\nUsing epoch %05d with %s: %0.5f' % (self.best_epochs, self.monitor, self.best))
                     self.model.set_weights(self.best_weights)  # set best model's weights
                     
-                    self.model_summary['selected_metrics'] = {self.monitor: np.float64(self.best)}
+                    self.model_summary[SELECTED_METRICS] = {self.monitor: np.float64(self.best)}
                 else:
-                    self.model_summary['selected_metrics'] = {self.monitor: np.float64(self.last_epoch_metric)}
+                    self.model_summary[SELECTED_METRICS] = {self.monitor: np.float64(self.last_epoch_metric)}
     
           #      print('model_summary: ', self.model_summary)   ##############################
                 end = get_time.now()
@@ -235,7 +242,7 @@ class accuinsight(Common):
                 self.path_for_setting_model_json = self.dict_path['model_json']
                 set_model_json_path(self.path_for_setting_model_json)
 
-                model_json_full_path = self.dict_path['model_json_full']
+                model_json_full_path = self.dict_path[RUN_MODEL_JSON_PATH]
 
                 with open(model_json_full_path, 'w', encoding='utf-8') as save_file:
                     json.dump(self.model_summary, save_file, indent="\t")
@@ -280,7 +287,7 @@ class accuinsight(Common):
                 self.dict_path = path.get_file_path(self.model, usedFramework='tensorflow')
                 # path for visual.json
                 path_for_setting_visual_json = self.dict_path['visual_json']
-                visual_json_full_path = self.dict_path['visual_json_full']
+                visual_json_full_path = self.dict_path[RUN_OBJ_VISUAL_JSON_PATH]
                 set_visual_json_path(path_for_setting_visual_json)
 
                 # classification
@@ -328,7 +335,7 @@ class accuinsight(Common):
         def run_and_log_function(self, original, x, y, kwargs):
             dict_path = path.get_file_path(self, usedFramework='tensorflow')
             path_for_setting_visual_csv = dict_path['visual_csv']
-            visual_csv_full_path = dict_path['visual_csv_full']
+            visual_csv_full_path = dict_path[RUN_MODEL_VISUAL_CSV_PATH]
 
             # set current run
             set_current_runs(RUN_NAME_TENSORFLOW)
