@@ -6,9 +6,12 @@ class Lifecycle:
     """
     The exposed class to user
     """
+    def __init__(self):
+        self.accu_keras = keras.accuinsight()
+        self.accu_tensorflow = tensorflow.accuinsight()
 
     def run_keras(self, tag=None):
-        keras.autolog(tag)
+        self.accu_keras.autolog(tag)
 
     def run_tensorflow(self, tag=None):
-        tensorflow.autolog(tag)
+        self.accu_tensorflow.autolog(tag)
