@@ -1,13 +1,11 @@
 import json
-from Accuinsight.modeler.core.Run.RunInfo.RunInfo import get_current_run
 from Accuinsight.modeler.core.LcConst.LcConst import RUN_OBJ_JSON_PATH, RUN_BASE_PATH
 from Accuinsight.modeler.core.LcConst.LcConst import ALL_MODEL_PARAMS, SELECTED_METRICS, SELECTED_PARAMS
 from Accuinsight.modeler.protos.life_cycle_pb2 import LcParam, LcMetric
 
 
 # load json data
-def _load_current_run():
-    run_info_json = get_current_run()
+def _load_current_run(run_info_json):
     data_path = run_info_json[RUN_BASE_PATH] + run_info_json[RUN_OBJ_JSON_PATH]
 
     with open(data_path) as json_file:
@@ -44,23 +42,16 @@ def parse_run_metrics(json_data):
 
     # selected_metrics
     selected_metrics = json_data[SELECTED_METRICS]
-    dummy_data = {
-        'rmse': 9.01244
-      },
-
     metric_keys = selected_metrics.keys()
 
     result_dict = {'metrics': []}
 
     count = 0
     for key in metric_keys:
-        timestamp = []
-        steps = []
-        values = []
+        timestamp = [str(count)]
+        steps = [str(count)]
+        values = [str(selected_metrics[key])]
 
-        values.append(str(selected_metrics[key]))
-        timestamp.append(str(count))
-        steps.append(str(count))
         count += 1
 
         result_dict['metrics'].append({'key': key,
@@ -82,9 +73,9 @@ def parse_run_metrics(json_data):
     return grpc_metrics
 
 
-def parse_run_result():
+def parse_run_result(run_info_json):
     result_dict = {'metrics': '', 'params': ''}
-    json_data = _load_current_run()
+    json_data = _load_current_run(run_info_json)
     grpc_params = parse_run_parameters(json_data=json_data)
     grpc_metrics = parse_run_metrics(json_data=json_data)
 
