@@ -19,9 +19,9 @@ def model_type(model_name):
         return 'pytorch'
 
     tmp_name = str(model_name)
-    if '(' in str(model_name):
+    if '(' in tmp_name:
         tmp_name = str(model_name)[:str(model_name).find('(')]
-    elif '<' in str(model_name):
+    elif '<' in tmp_name:
         tmp_name = str(model_name).split('.')[0][1:]
 
     if any(i in tmp_name for i in ONEVS):
@@ -55,6 +55,7 @@ def trial_number_all(DB_path, file_type):
     os.chdir(r'..')                  ######## 상위 디렉토리로 이동 (경우에 따라서 변경 필요!!!!!) ########
     return str(trial_num)
 
+
 def trial_num_json(DB_path, file_type):
     os.chdir(DB_path)
     str_file_type = '*.' + file_type
@@ -116,7 +117,11 @@ class from_model(object):
         parkey = [i for i in self.parDict.keys() if '__' in i]
         parkey = list(map(lambda x: x[x.find('__') + 2:], parkey))
         if len(parkey) != 0:
-            parkey.remove('random_state')
+            try:
+                parkey.remove('random_state')
+            except ValueError:
+                pass
+
             return parkey
         else:
             return list(self.parDict.keys())
