@@ -5,7 +5,6 @@ class WorkspaceRunLog:
     def __init__(self):
         self._workspace_run_id = None
         self._is_success = False
-        self._stop_flag = False
         self._stop_timeout = 60
 
     def __eq__(self, other):
@@ -32,24 +31,6 @@ class WorkspaceRunLog:
     def is_success(self, is_success):
         self._is_success = is_success
 
-    @property
-    def stop_flag(self):
-        """If stopping the workspace after run needed."""
-        return self._stop_flag
-
-    @stop_flag.setter
-    def stop_flag(self, stop_flag):
-        self._stop_flag = stop_flag
-
-    @property
-    def stop_timeout(self):
-        """Workspace stop timeout."""
-        return self._stop_timeout
-
-    @stop_timeout.setter
-    def stop_timeout(self, stop_timeout):
-        self._stop_timeout = stop_timeout
-
     @classmethod
     def from_proto(cls, proto):
         pass
@@ -65,7 +46,5 @@ class WorkspaceRunLog:
 
         data['workspaceRunId'] = self.workspace_run_id
         data['isSuccess'] = self.is_success
-        data['stopFlag'] = self.stop_flag
-        data['stopTimeout'] = self.stop_timeout
 
         return json.dumps(data, indent=2)
