@@ -33,5 +33,6 @@ def get_best_model_path(run_id = None, path = None):
     else:
         best_model_path_dict['json'] = best_model_path[1]
         best_model_path_dict['h5'] = best_model_path[0]
-    return(best_model_path_dict)
-    
+
+    return best_model_path_dict
+
