@@ -35,40 +35,27 @@ def get_os_env(env_type='LC', env_path=None, env_file=None):
 
 def is_in_ipython():
     return 'ipykernel_launcher.py' in sys.argv[0]
-    
-    
-def __list_jupyterlab_workspace(target_path):
-    file_lists = []
-    for (dirpath, dirnames, filenames) in os.walk(target_path):
-        for fn in filenames:
-            if not fn.endswith('.swp'):
-                if 'auto' in fn: continue
-                file_lists.append(fn)
-            break
-    return file_lists
-
-
-def __get_current_file(target_path, target_file):
-    with open(target_path + '/' + target_file, 'r') as tf:
-        strlines = tf.readlines()
-        aaa = json.loads(strlines[0])
-        current_notebook = aaa['data']['layout-restorer:data']['main']['current']
-    return current_notebook
-
-
-def __install_package(package_name):
-    subprocess.check_call([sys.executable, "-m", "pip", "install", package_name])
 
 
 def get_current_notebook():
     if is_in_ipython():
         target_path = LcConst.ENV_JUPYTER_WORKSPACE
         # '/home/notebook/.jupyter/lab/workspaces'
-        if os.path.isdir(target_path): # if jupyter lab
-            return __get_current_file(target_path=target_path,
-                                      target_file=__list_jupyterlab_workspace(target_path=target_path)[0]
-                                      ).split(':')[1]
+        if os.path.isdir(target_path):  # if jupyter lab
+            file_lists = list()
+            for (dir_path, dir_names, file_names) in os.walk(target_path):
+                for fn in file_names:
+                    if not fn.endswith('.swp'):
+                        if 'auto' in fn:
+                            continue
+                        file_lists.append(fn)
+                    break
+
+            with open(target_path + '/' + file_lists[0], 'r') as tf:
+                strlines = tf.readlines()
+                json_file = json.loads(strlines[0])
+                return json_file['data']['layout-restorer:data']['main']['current'].split(':')[1]
         else:
-            __install_package('ipyparams')
+            subprocess.check_call([sys.executable, "-m", "pip", "install", 'ipyparams'])
             import ipyparams
             return ipyparams.notebook_name
